package rlemaigr.classdiagrameditor.model;

import org.eclipse.ui.views.properties.*;

public class AttributeModel extends ObjectModel
{
	private String identifier;
	private String type;
	private int visibility;
	
	private IPropertyDescriptor [] descriptors;

	public static final String PROPERTY_SIGNATURE_CHANGED = "signature";
	public static final int PUBLIC = 0;
	public static final int PRIVATE = 1;
	public static final int PROTECTED = 2;

	public static final String ID_PROPERTY_IDENTIFIER = "identifier";
	public static final String ID_PROPERTY_TYPE = "return type";
	public static final String ID_PROPERTY_VISIBILITY = "visibilit";

	public AttributeModel()
	{
		setSignature(PUBLIC, "no_type", "no_identifier");
	}
	public AttributeModel(int visibility, String type, String identifier)
	{
		setSignature(visibility, type, identifier);
	}
	public void setSignature(int visibility, String type, String identifier)
	{
		this.visibility = visibility;
		this.type = type;
		this.identifier = identifier;
		firePropertyChange(PROPERTY_SIGNATURE_CHANGED, null, null);
	}
	public int getVisibility()
	{
		return visibility;
	}
	public String getType()
	{
		return type;
	}
	public String getIdentifier()
	{
		return identifier;
	}
	public String toString()
	{
		return type + " " + identifier;
	}
	public void setType(String type)
	{
		this.type = type;
		firePropertyChange(PROPERTY_SIGNATURE_CHANGED, null, null);
	}
	public void setIdentifier(String identifier)
	{
		this.identifier = identifier;
		firePropertyChange(PROPERTY_SIGNATURE_CHANGED, null, null);
	}
	public void setVisibility(int visibility)
	{
		if (visibility >= 0 && visibility < 3)
		{
			this.visibility = visibility;
			firePropertyChange(PROPERTY_SIGNATURE_CHANGED, null, null);
		}
	}
	public IPropertyDescriptor[] getPropertyDescriptors()
	{
		if (descriptors == null)
		{
			IPropertyDescriptor[] superDescriptors = super.getPropertyDescriptors();
			descriptors = new IPropertyDescriptor[superDescriptors.length + 3];
			for (int i = 0; i < superDescriptors.length; i++)
				descriptors[i] = superDescriptors[i];
			descriptors[superDescriptors.length] =
				new TextPropertyDescriptor(ID_PROPERTY_TYPE, "type");
			descriptors[superDescriptors.length + 1] =
				new TextPropertyDescriptor(ID_PROPERTY_IDENTIFIER, "identificateur");
			descriptors[superDescriptors.length + 2] =
				new ComboBoxPropertyDescriptor(
					ID_PROPERTY_VISIBILITY,
					"visibilit",
					new String[] { "public", "protected", "private" });
		}
		return descriptors;
	}
	public void setPropertyValue(Object propName, Object val)
	{
		if (propName instanceof String)
		{
			if (((String) propName).equals(ID_PROPERTY_TYPE))
				setType(val.toString());
			else if (((String) propName).equals(ID_PROPERTY_IDENTIFIER))
				setIdentifier(val.toString());
			else if (((String) propName).equals(ID_PROPERTY_VISIBILITY))
			{
				if (((Integer) val).intValue() == 0)
					setVisibility(PUBLIC);
				else if (((Integer) val).intValue() == 2)
					setVisibility(PRIVATE);
				else if (((Integer) val).intValue() == 1)
					setVisibility(PROTECTED);
			}
		}
		else
			super.setPropertyValue(propName, val);
	}
	public Object getPropertyValue(Object propName)
	{
		if (propName instanceof String)
		{
			if (((String) propName).equals(ID_PROPERTY_TYPE))
				return type;
			else if (((String) propName).equals(ID_PROPERTY_IDENTIFIER))
				return identifier;
			else if (((String) propName).equals(ID_PROPERTY_VISIBILITY))
			{
				if (visibility == PUBLIC)
					return new Integer(0);
				else if (visibility == PRIVATE)
					return new Integer(2);
				else if (visibility == PROTECTED)
					return new Integer(1);
				else
					return super.getPropertyValue(propName);
			}
			else
				return super.getPropertyValue(propName);
		}
		else
			return super.getPropertyValue(propName);
	}
}