package rlemaigr.classdiagrameditor.model;

import org.eclipse.draw2d.geometry.*;
import org.eclipse.ui.views.properties.*;
import java.util.*;

public class ClassModel extends DiagramElementModel
{
	private MethodListModel methods;
	private AttributeListModel attributes;
	private String name;

	private List sourceConnections;
	private List targetConnections;

	private static IPropertyDescriptor[] descriptors;

	public static final String PROPERTY_NAME_CHANGED = "name";
	public static final String PROPERTY_SOURCE_CONNECTIONS_CHANGED = "source connections changed";
	public static final String PROPERTY_TARGET_CONNECTIONS_CHANGED = "target connections changed";

	private static final String ID_PROPERTY_NAME = "name";

	public ClassModel()
	{
		methods = new MethodListModel();
		attributes = new AttributeListModel();
		sourceConnections = new ArrayList();
		targetConnections = new ArrayList();
		name = "pas de nom";
		setSize(new Dimension(50, 50));
	}

	public MethodListModel getMethodList()
	{
		return methods;
	}
	public AttributeListModel getAttributeList()
	{
		return attributes;
	}
	public void setMethodList(MethodListModel ml)
	{
		this.methods = ml;
	}
	public void setAttributeList(AttributeListModel al)
	{
		this.attributes = al;
	}
	public void setName(String name)
	{
		String save = getName();
		this.name = name;
		firePropertyChange(PROPERTY_NAME_CHANGED, save, name);
	}
	public String getName()
	{
		return name;
	}
	
	protected void addSourceConnection(InheritanceModel connection)
	{
		sourceConnections.add(connection);
		firePropertyChange(PROPERTY_SOURCE_CONNECTIONS_CHANGED, null, connection);
	}
	protected void addTargetConnection(InheritanceModel connection)
	{
		targetConnections.add(connection);
		firePropertyChange(PROPERTY_TARGET_CONNECTIONS_CHANGED, null, connection);
	}
	protected void removeSourceConnection(InheritanceModel connection)
	{
		sourceConnections.remove(connection);
		firePropertyChange(PROPERTY_SOURCE_CONNECTIONS_CHANGED, null, connection);
	}
	protected void removeTargetConnection(InheritanceModel connection)
	{
		targetConnections.remove(connection);
		firePropertyChange(PROPERTY_TARGET_CONNECTIONS_CHANGED, null, connection);
	}
	public List getSourceConnections()
	{
		return sourceConnections;
	}
	public List getTargetConnections()
	{
		return targetConnections;
	}
	public IPropertyDescriptor[] getPropertyDescriptors()
	{
		if (descriptors == null)
		{
			IPropertyDescriptor[] superDescriptors = super.getPropertyDescriptors();
			descriptors = new IPropertyDescriptor[superDescriptors.length + 1];
			for (int i = 0; i < superDescriptors.length; i++)
				descriptors[i] = superDescriptors[i];
			descriptors[superDescriptors.length] = new TextPropertyDescriptor(ID_PROPERTY_NAME, "name");
		}
		return descriptors;
	}
	public void setPropertyValue(Object propName, Object val)
	{
		if (propName instanceof String && ((String) propName).equals(ID_PROPERTY_NAME))
			setName((String) val);
		else
			super.setPropertyValue(propName, val);
	}
	public Object getPropertyValue(Object propName)
	{
		if (propName instanceof String && ((String) propName).equals(ID_PROPERTY_NAME))
			return getName();
		else
			return super.getPropertyValue(propName);
	}
}
