package rlemaigr.classdiagrameditor.model;

import java.util.*;
import org.eclipse.draw2d.*;

public class InheritanceModel extends ObjectModel
{
	private ClassModel source;
	private ClassModel target;
	private List bendpoints;

	public static final String PROPERTY_CONSTRAINT_CHANGED = "constraint changed";

	public InheritanceModel()
	{
		bendpoints = new ArrayList();
	}
	public void setSource(ClassModel newSource)
	{
		if (source == newSource)
			return;

		ClassModel oldSource = source;
		source = newSource;
		if (oldSource != null)
			oldSource.removeSourceConnection(this);
		if (newSource != null)
			source.addSourceConnection(this);
	}
	public void setTarget(ClassModel newTarget)
	{
		if (target == newTarget)
			return;

		ClassModel oldTarget = target;
		target = newTarget;
		if (oldTarget != null)
			oldTarget.removeTargetConnection(this);
		if (newTarget != null)
			target.addTargetConnection(this);
	}
	public ClassModel getSource()
	{
		return source;
	}
	public ClassModel getTarget()
	{
		return target;
	}
	public List getConstraint()
	{
		return bendpoints;
	}
	public void setConstraint(List bendpoints)
	{
		this.bendpoints = bendpoints;
		firePropertyChange(PROPERTY_CONSTRAINT_CHANGED, null, null);
	}
	public void addBendpoint(Bendpoint bendpoint, int index)
	{
		bendpoints.add(index, bendpoint);
		firePropertyChange(PROPERTY_CONSTRAINT_CHANGED, null, null);
	}
	public void removeBendpoint(Bendpoint bendpoint)
	{
		bendpoints.remove(bendpoint);
		firePropertyChange(PROPERTY_CONSTRAINT_CHANGED, null, null);
	}
	public Bendpoint removeBendpoint(int index)
	{
		Bendpoint save = (Bendpoint) bendpoints.get(index);
		bendpoints.remove(index);
		firePropertyChange(PROPERTY_CONSTRAINT_CHANGED, null, null);
		return save;
	}
	public Bendpoint getBendpoint(int index)
	{
		return (Bendpoint) bendpoints.get(index);
	}
	public void replaceBendpoint(int index, Bendpoint newBendpoint)
	{
		bendpoints.remove(index);
		bendpoints.add(index, newBendpoint);
		firePropertyChange(PROPERTY_CONSTRAINT_CHANGED, null, null);
	}
}
